"use client";
import { useRouter } from 'next/navigation'; // Not from 'next/router'
import { useEffect, useRef, useState } from 'react';
const SearchContainer = ({ query, searchKey, isLoading, error, products, handleSearch }) => {
  const [isVisible, setIsVisible] = useState(false); // Control visibility of the search container
  const containerRef = useRef(null); // Reference to the container for click-outside detection
  const router = useRouter();
  // Show/hide the search container based on query and searchKey
  useEffect(() => {
    if (query.trim() && searchKey) {
      setIsVisible(true);
    } else {
      setIsVisible(false);
    }
  }, [query, searchKey]);

  // Handle click outside to hide the container
  useEffect(() => {
    const handleClickOutside = (event) => {
      if (containerRef.current && !containerRef.current.contains(event.target)) {
        setIsVisible(false);
      }
    };

    document.addEventListener('mousedown', handleClickOutside);
    return () => {
      document.removeEventListener('mousedown', handleClickOutside);
    };
  }, []);

  return (
    <>
      {isVisible && (
        <div
          ref={containerRef}
          className="mt-2 absolute z-10 left-1/2  -translate-x-1/2  bg-white w-[90vw] md:w-full max-w-md py-2 rounded-md shadow-lg border"
        >
          {isLoading && <p className="px-4 py-2 text-gray-500">Loading...</p>}
          {error && (
            <p className="px-4 py-2 text-red-500">
              {error.message || 'An error occurred'}
            </p>
          )}
          {products.length > 0 && (
            <ul className="max-h-80 overflow-y-auto">
              {products.map((product) => (
                <li
                  key={product.product_id}
                  className="px-4 py-3 hover:bg-gray-100 cursor-pointer flex gap-3 items-center border-b last:border-b-0"
                  onClick={() => router.push(`/products/${product.product_id}` , setIsVisible(false))} // Navigate to product page and hide the container
                >
                  <img
                    src={`${process.env.NEXT_PUBLIC_IMAGE_URL}/${product.product_image}`}
                    alt={product.product_name}
                    className="w-12 h-12 object-cover rounded"
                  />
                  <div className="flex-1">
                    <h3 className="text-sm font-medium">{product.product_name}</h3>
                    <p className="text-xs text-gray-500">{product.category_name}</p>
                    <p className="text-sm text-green-600 font-bold mt-1">
                      {product.is_discounted
                        ? `$${product.product_discounted_price}`
                        : `$${product.product_price}`}
                      {product.is_discounted && (
                        <span className="text-red-500 line-through ml-2 font-normal text-xs">
                          ${product.product_price}
                        </span>
                      )}
                    </p>
                  </div>
                </li>
              ))}
            </ul>
          )}
          {searchKey && products.length === 0 && !isLoading && !error && (
            <p className="px-4 py-2 text-gray-500">No products found for "{query}"</p>
          )}
        </div>
      )}
    </>
  );
};

export default SearchContainer;